searchData={"items":[{"type":"module","title":"CloudfrontSigner","doc":"Elixir implementation of cloudfront's signed url algorithm.  Basic usage is:\n\n```\nCloudfrontSigner.Distribution.from_config(:scope, :key)\n|> CloudfrontSigner.sign(\"some/path\", [arg: \"val\"], some_expiry)\n```","ref":"CloudfrontSigner.html"},{"type":"function","title":"CloudfrontSigner.sign/4","doc":"Signs a url for the given `Distribution.t` struct constructed from the `path` and `query_params` provided.  `expiry`\nis in seconds.","ref":"CloudfrontSigner.html#sign/4"},{"type":"module","title":"CloudfrontSigner.Distribution","doc":"Representation of a cloudfront distribution for the purpose of computing a signed url.\nWe need the address of the distribution and the private key for RSA signature generation","ref":"CloudfrontSigner.Distribution.html"},{"type":"function","title":"CloudfrontSigner.Distribution.from_config/2","doc":"Creates a `Distribution.t` record from the contents of `Application.get_env(app, scope)`","ref":"CloudfrontSigner.Distribution.html#from_config/2"},{"type":"function","title":"CloudfrontSigner.Distribution.from_map/1","doc":"Creates a `Distribution` struct from a map of attributes.\n\nIf the map contains a `:private_key` that is a binary PEM string, it will be decoded\ninto its internal representation. Other attributes (`:domain` and `:key_pair_id`) are\ncopied as-is into the struct.","ref":"CloudfrontSigner.Distribution.html#from_map/1"},{"type":"type","title":"CloudfrontSigner.Distribution.t/0","doc":"","ref":"CloudfrontSigner.Distribution.html#t:t/0"},{"type":"module","title":"CloudfrontSigner.DistributionRegistry","doc":"Agent to store and fetch cloudfront distributions, to avoid expensive runtime pem decodes","ref":"CloudfrontSigner.DistributionRegistry.html"},{"type":"function","title":"CloudfrontSigner.DistributionRegistry.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"CloudfrontSigner.DistributionRegistry.html#child_spec/1"},{"type":"function","title":"CloudfrontSigner.DistributionRegistry.get_distribution/2","doc":"Gets a distribution from the registry. If not found, creates it from config and caches it.","ref":"CloudfrontSigner.DistributionRegistry.html#get_distribution/2"},{"type":"function","title":"CloudfrontSigner.DistributionRegistry.start_link/1","doc":"","ref":"CloudfrontSigner.DistributionRegistry.html#start_link/1"},{"type":"module","title":"CloudfrontSigner.Policy","doc":"Defines a cloudfront signature policy, and a string coercion method for it","ref":"CloudfrontSigner.Policy.html"},{"type":"function","title":"CloudfrontSigner.Policy.generate_signature_and_policy/2","doc":"Generates a CloudFront URL signature and policy for a given resource.\n\nTakes a policy struct containing the resource URL and expiry time, along with an RSA private key,\nand returns a tuple containing the URL-safe base64 encoded signature and the base64 encoded policy.\n\nThe signature is generated using SHA-1 with RSA encryption (SHA1withRSA) and is URL-safe encoded.\nThe policy is a JSON document that specifies what resource is being accessed and when the signature expires.","ref":"CloudfrontSigner.Policy.html#generate_signature_and_policy/2"},{"type":"function","title":"Parameters - CloudfrontSigner.Policy.generate_signature_and_policy/2","doc":"* `policy` - A `Policy` struct containing:\n    * `resource` - The URL of the CloudFront resource to be accessed\n    * `expiry` - Unix timestamp when the signature should expire\n  * `private_key` - An RSA private key in ASN.1 format (decoded from PEM)","ref":"CloudfrontSigner.Policy.html#generate_signature_and_policy/2-parameters"},{"type":"function","title":"Returns - CloudfrontSigner.Policy.generate_signature_and_policy/2","doc":"* `{signature, encoded_policy}` where:\n    * `signature` - URL-safe base64 encoded signature\n    * `encoded_policy` - Base64 encoded JSON policy document","ref":"CloudfrontSigner.Policy.html#generate_signature_and_policy/2-returns"},{"type":"type","title":"CloudfrontSigner.Policy.rsa_private_key/0","doc":"Type definition for an RSA private key in ASN.1 format.\nThe tuple elements represent:\n- :RSAPrivateKey - The key type identifier\n- :\"two-prime\" - The RSA version identifier\n- modulus - The RSA modulus n\n- publicExponent - The public exponent e\n- privateExponent - The private exponent d\n- prime1 - The first prime factor p of n\n- prime2 - The second prime factor q of n\n- exponent1 - d mod (p-1)\n- exponent2 - d mod (q-1)\n- coefficient - The CRT coefficient q^(-1) mod p\n- otherPrimeInfos - Optional additional prime info (usually :asn1_NOVALUE)","ref":"CloudfrontSigner.Policy.html#t:rsa_private_key/0"},{"type":"type","title":"CloudfrontSigner.Policy.t/0","doc":"","ref":"CloudfrontSigner.Policy.html#t:t/0"},{"type":"extras","title":"Readme","doc":"# CloudfrontSigner\n\nElixir implementation of Cloudfront's url signature algorithm. Supports expiration policies and\nruntime configurable distributions.\n\nThe main benefits that this library provides are:\n\n- Runtime configurable distributions\n- Caching of PEM decodes","ref":"readme.html"},{"type":"extras","title":"Installation - Readme","doc":"Add `cloudfront_signer` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:cloudfront_signer, \"~> 1.0.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuring a Distribution - Readme","doc":"Configure a distribution with:\n\n```elixir\nconfig :my_app, :my_distribution,\n  domain: \"https://some.cloudfront.domain\",\n  private_key: System.get_env(\"PRIVATE_KEY\"), # or {:file, \"/path/to/key\"}\n  key_pair_id: System.get_env(\"KEY_PAIR_ID\")\n```","ref":"readme.html#configuring-a-distribution"},{"type":"extras","title":"Signing a URL without Caching PEM Decodes - Readme","doc":"Caching PEM decodes is a wise choice, but if you don't want to cache them, you can do the following:\n\n```elixir\nCloudfrontSigner.Distribution.from_config(:my_app, :my_distribution)\n|> CloudfrontSigner.sign(path, [arg: \"value\"], expiry_in_seconds)\n```","ref":"readme.html#signing-a-url-without-caching-pem-decodes"},{"type":"extras","title":"Caching PEM Decodes - Readme","doc":"If you want to cache PEM decodes, you can use the distribution registry. \nAdd `CloudfrontSigner.DistributionRegistry` to your application's supervision tree:\n\n```elixir\n# In your application.ex\ndef start(_type, _args) do\n  children = [\n    # ... other children ...\n    CloudfrontSigner.DistributionRegistry\n  ]\n\n  opts = [strategy: :one_for_one, name: YourApp.Supervisor]\n  Supervisor.start_link(children, opts)\nend\n```\n\nThen use it like:\n\n```elixir\nCloudfrontSigner.DistributionRegistry.get_distribution(:my_app, :my_distribution)\n|> CloudfrontSigner.sign(path, [arg: \"value\"], expiry)\n```","ref":"readme.html#caching-pem-decodes"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)\n\n## [Unreleased]","ref":"changelog.html"},{"type":"extras","title":"1.0.0 - 2025-02-10 - Changelog","doc":"","ref":"changelog.html#1-0-0-2025-02-10"},{"type":"extras","title":"⚠️ Breaking Changes - Changelog","doc":"- Remove Application module - users must now add `CloudfrontSigner.DistributionRegistry` to their own supervision tree\n\n#### Example\n\n```elixir\n# In your application.ex\ndef start(_type, _args) do\n  children = [\n    # ... other children ...\n    CloudfrontSigner.DistributionRegistry\n  ]\n  \n  opts = [strategy: :one_for_one, name: YourApp.Supervisor]\n  Supervisor.start_link(children, opts)\nend\n```","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"🚀 Features - Changelog","doc":"- Enforce key order in AWS Policy using Jason.OrderedObject\n- Add support for Elixir version 1.15\n- Add Styler for consistent code formatting","ref":"changelog.html#features"},{"type":"extras","title":"🚜 Refactor - Changelog","doc":"- Remove unused Poison dependency\n- Fix test expectations in CloudfrontSignerTest\n- Remove test for non-existent module\n- Replace Timex with DateTime","ref":"changelog.html#refactor"},{"type":"extras","title":"📚 Documentation - Changelog","doc":"- Update README with guidance for installing via hex\n- Add directions for adding registry to application supervision tree\n- Improve function docs and typespecs\n- Improve test documentation and formatting","ref":"changelog.html#documentation"},{"type":"extras","title":"0.2.0 - 2025-01-28 - Changelog","doc":"","ref":"changelog.html#0-2-0-2025-01-28"},{"type":"extras","title":"🚀 Features - Changelog","doc":"- Swap Poison for Jason","ref":"changelog.html#features"},{"type":"extras","title":"🐛 Bug Fixes - Changelog","doc":"- @spec should match function guards\n- Optional argument as last arg","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"🚜 Refactor - Changelog","doc":"- Refactor to custom policy","ref":"changelog.html#refactor"},{"type":"extras","title":"📚 Documentation - Changelog","doc":"- Add docs\n- Syntax fix","ref":"changelog.html#documentation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}